[ANNOUNCEMENT] TEST RELEASE: Cygwin 2.8.1-0.1
Brian Inglis
Brian.Inglis@SystematicSw.ab.ca
Fri Jun 23 18:47:00 GMT 2017
On 2017-06-23 12:25, Corinna Vinschen wrote:
> On Jun 23 19:52, Marco Atzeri wrote:
>> On 22/06/2017 15:58, Corinna Vinschen wrote:
>>> I uploaded a new Cygwin test release 2.8.1-0.1
>>> I'm planning for a release next week. Please test.
>> $ /etc/postinstall/cygwin-doc.sh
>> Can't find directory '/usr/share/doc/cygwin-2.8.1'
> Fixed in git.
Darn you were fast!
You might want to apply the rest of the attached format-patch,
as it makes things clearer, more maintainable, and shorter.
--
Take care. Thanks, Brian Inglis, Calgary, Alberta, Canada
-------------- next part --------------
From 3f92d6ec6f0e715cbd6629634e66a306603532a5 Mon Sep 17 00:00:00 2001
From: Brian Inglis <Brian.Inglis@SystematicSW.ab.ca>
Date: Fri, 23 Jun 2017 12:38:16 -0600
Subject: [PATCH] cygwin: doc: Fix doc install path in postinstall script
---
winsup/doc/etc.postinstall.cygwin-doc.sh | 62 +++++++++++---------------------
1 file changed, 20 insertions(+), 42 deletions(-)
diff --git a/winsup/doc/etc.postinstall.cygwin-doc.sh b/winsup/doc/etc.postinstall.cygwin-doc.sh
index dbb641219..ff1d9624e 100755
--- a/winsup/doc/etc.postinstall.cygwin-doc.sh
+++ b/winsup/doc/etc.postinstall.cygwin-doc.sh
@@ -26,9 +26,7 @@ do
fi
done
-cygver=$($un -r) # release - numeric version (build info)
-cygver=${cygver%\(*\)} # strip build info
-doc=/usr/share/doc/cygwin-$cygver
+doc=/usr/share/doc/cygwin-doc
html=$doc/html
smpc_dir="$($cygp $CYGWINFORALL -P -U)/Cygwin"
@@ -50,43 +48,23 @@ fi
# mkshortcut works only in current directory - change to Cygwin Start Menu
cd "$smpc_dir" || exit 2 # quit if not found
-# User Guide PDF & HTML
-p=$doc/cygwin-ug-net.pdf
-n="User Guide (PDF)"
-d="PDF Cygwin User Guide"
-
-[ -r $p ] && $mks -n "$n" -d "$d" $p
-
-i=$html/cygwin-ug-net/index.html
-n="User Guide (HTML)"
-d="HTML Cygwin User Guide"
-
-[ -r $i ] && $mks -n "$n" -d "$d" $i
-
-# API PDF & HTML
-p=$doc/cygwin-api.pdf
-n="API (PDF)"
-d="PDF Cygwin API Reference"
-
-[ -r $p ] && $mks -n "$n" -d "$d" $p
-
-i=$html/cygwin-api/index.html
-n="API (HTML)"
-d="HTML Cygwin API Reference"
-
-[ -r $i ] && $mks -n "$n" -d "$d" $i
-
-# Home Page URL
-h=$site/index.html
-n="Home Page"
-d="Cygwin $n"
-
-$mks -n "$n" -d "$d" $h
-
-# FAQ URL
-h=$site/faq.html
-n="FAQ"
-d="Cygwin Frequently Asked Questions (with answers)"
-
-$mks -n "$n" -d "$d" $h
+# create User Guide and API PDF and HTML shortcuts
+while read t n d
+do
+ [ -r $t ] && $mks -n "$n" -d "$d" $t
+done <<EOF
+$doc/cygwin-ug-net.pdf User\ Guide\ \(PDF\) Cygwin\ User\ Guide\ PDF
+$html/cygwin-ug-net/index.html User\ Guide\ \(HTML\) Cygwin\ User\ Guide\ HTML
+$doc/cygwin-api.pdf API\ \(PDF\) Cygwin\ API\ Reference\ PDF
+$html/cygwin-api/index.html API\ \(HTML\) Cygwin\ API\ Reference\ HTML
+EOF
+
+# create Home Page and FAQ URL link shortcuts
+while read t n d
+do
+ $mks -n "$n" -d "$d" $t
+done <<EOF
+$site/index.html Home\ Page Cygwin\ Home\ Page\ Link
+$site/faq.html FAQ Cygwin\ Frequently\ Asked\ Questions\ Link
+EOF
--
2.12.3
-------------- next part --------------
--
Problem reports: http://cygwin.com/problems.html
FAQ: http://cygwin.com/faq/
Documentation: http://cygwin.com/docs.html
Unsubscribe info: http://cygwin.com/ml/#unsubscribe-simple
More information about the Cygwin
mailing list